==> percona-xtrabackup_8.4.0-1.orig.tar.gz: percona-xtrabackup-8.4.0-1/storage/innobase/include/ut0class_life_cycle.h <==
/*****************************************************************************

Copyright (c) 2020, 2024, Oracle and/or its affiliates.

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License, version 2.0, as published by the
Free Software Foundation.

This program is designed to work with certain software (including
but not limited to OpenSSL) that is licensed under separate terms,
as designated in a particular file or component or in included license
documentation.  The authors of MySQL hereby grant you an additional
permission to link the program and your derivative works with the
separately licensed software that they have either included with
the program or referenced in the documentation.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License, version 2.0,
for more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

*****************************************************************************/

/** @file include/ut0class_life_cycle.h
Utilities related to class lifecycle. */

#ifndef ut0class_life_cycle_h
#define ut0class_life_cycle_h

namespace ut {

/**
A utility class which, if inherited from, prevents the descendant class
from being copied, moved, or assigned.
This is useful for guard classes.
*/
class Non_copyable {
 public:
  Non_copyable(const Non_copyable &) = delete;
  Non_copyable &operator=(const Non_copyable &) = delete;

 protected:
  Non_copyable() = default;
  ~Non_copyable() = default;  /// Protected non-virtual destructor
};

} /* namespace ut */

#endif /* ut0class_life_cycle_h */

==> percona-xtrabackup-80_8.0.23-16.orig.tar.gz: percona-xtrabackup-8.0.23-16/storage/innobase/include/ut0class_life_cycle.h <==
/*****************************************************************************

Copyright (c) 2020, Oracle and/or its affiliates. All Rights Reserved.

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License, version 2.0, as published by the
Free Software Foundation.

This program is also distributed with certain software (including but not
limited to OpenSSL) that is licensed under separate terms, as designated in a
particular file or component or in included license documentation. The authors
of MySQL hereby grant you an additional permission to link the program and
your derivative works with the separately licensed software that they have
included with MySQL.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License, version 2.0,
for more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

*****************************************************************************/

/** @file include/ut0class_life_cycle.h
Utilities related to class lifecycle. */

#ifndef ut0class_life_cycle_h
#define ut0class_life_cycle_h

namespace ut {

/**
A utility class which, if inherited from, prevents the descendant class
from being copied, moved, or assigned.
This is useful for guard classes.
*/
class Non_copyable {
 public:
  Non_copyable(const Non_copyable &) = delete;
  Non_copyable &operator=(const Non_copyable &) = delete;

 protected:
  Non_copyable() = default;
  ~Non_copyable() = default;  /// Protected non-virtual destructor
};

} /* namespace ut */

#endif /* ut0class_life_cycle_h */
